@@ -20,3 +20,6 @@ def test_prediction_parser(dummy_suite_json):
     assert p1(fudged_item)
 
 
+def test_prediction_parse_cleft():
+    p0 = Prediction(0, "((7;%np_mismatch%)-(7;%np_match%))+(((6;%vp_mismatch%)+(7;%vp_mismatch%))-((6;%vp_match%)+(7;%vp_match%)))>0")
+    p1 = Prediction(1, "((9;%what_nogap%) =  (9;%that_nogap%))& ((6;%what_subjgap%) =  (6;%that_subjgap%)) ")
